@@ -73,14 +73,14 @@ class LogEntry(models.Model):
 
     def __str__(self):
         if self.is_addition():
-            return gettext('Added "%(object)s".') % {'object': self.object_repr}
+            return gettext('Added “%(object)s”.') % {'object': self.object_repr}
         elif self.is_change():
-            return gettext('Changed "%(object)s" - %(changes)s') % {
+            return gettext('Changed “%(object)s” — %(changes)s') % {
                 'object': self.object_repr,
                 'changes': self.get_change_message(),
             }
         elif self.is_deletion():
-            return gettext('Deleted "%(object)s."') % {'object': self.object_repr}
+            return gettext('Deleted “%(object)s.”') % {'object': self.object_repr}
 
         return gettext('LogEntry Object')
 
@@ -108,17 +108,17 @@ class LogEntry(models.Model):
                 if 'added' in sub_message:
                     if sub_message['added']:
                         sub_message['added']['name'] = gettext(sub_message['added']['name'])
-                        messages.append(gettext('Added {name} "{object}".').format(**sub_message['added']))
+                        messages.append(gettext('Added {name} “{object}”.').format(**sub_message['added']))
                     else:
                         messages.append(gettext('Added.'))
 
                 elif 'changed' in sub_message:
                     sub_message['changed']['fields'] = get_text_list(
-                        sub_message['changed']['fields'], gettext('and')
+                        [gettext(field_name) for field_name in sub_message['changed']['fields']], gettext('and')
                     )
                     if 'name' in sub_message['changed']:
                         sub_message['changed']['name'] = gettext(sub_message['changed']['name'])
-                        messages.append(gettext('Changed {fields} for {name} "{object}".').format(
+                        messages.append(gettext('Changed {fields} for {name} “{object}”.').format(
                             **sub_message['changed']
                         ))
                     else:
@@ -126,7 +126,7 @@ class LogEntry(models.Model):
 
                 elif 'deleted' in sub_message:
                     sub_message['deleted']['name'] = gettext(sub_message['deleted']['name'])
-                    messages.append(gettext('Deleted {name} "{object}".').format(**sub_message['deleted']))
+                    messages.append(gettext('Deleted {name} “{object}”.').format(**sub_message['deleted']))
 
             change_message = ' '.join(msg[0].upper() + msg[1:] for msg in messages)
             return change_message or gettext('No fields changed.')
