@@ -1,15 +1,12 @@
 import inspect
 import re
-import warnings
 
 from django.apps import apps as django_apps
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured, PermissionDenied
 from django.middleware.csrf import rotate_token
 from django.utils.crypto import constant_time_compare
-from django.utils.deprecation import RemovedInDjango21Warning
 from django.utils.module_loading import import_string
-from django.utils.translation import LANGUAGE_SESSION_KEY
 
 from .signals import user_logged_in, user_logged_out, user_login_failed
 
@@ -67,7 +64,12 @@ def authenticate(request=None, **credentials):
     """
     for backend, backend_path in _get_backends(return_tuples=True):
         try:
-            user = _authenticate_with_backend(backend, backend_path, request, credentials)
+            inspect.getcallargs(backend.authenticate, request, **credentials)
+        except TypeError:
+            # This backend doesn't accept these credentials as arguments. Try the next one.
+            continue
+        try:
+            user = backend.authenticate(request, **credentials)
         except PermissionDenied:
             # This backend says to stop in our tracks - this user should not be allowed in at all.
             break
@@ -81,41 +83,6 @@ def authenticate(request=None, **credentials):
     user_login_failed.send(sender=__name__, credentials=_clean_credentials(credentials), request=request)
 
 
-def _authenticate_with_backend(backend, backend_path, request, credentials):
-    credentials = credentials.copy()  # Prevent a mutation from propagating.
-    args = (request,)
-    # Does the backend accept a request argument?
-    try:
-        inspect.getcallargs(backend.authenticate, request, **credentials)
-    except TypeError:
-        args = ()
-        credentials.pop('request', None)
-        # Does the backend accept a request keyword argument?
-        try:
-            inspect.getcallargs(backend.authenticate, request=request, **credentials)
-        except TypeError:
-            # Does the backend accept credentials without request?
-            try:
-                inspect.getcallargs(backend.authenticate, **credentials)
-            except TypeError:
-                # This backend doesn't accept these credentials as arguments. Try the next one.
-                return None
-            else:
-                warnings.warn(
-                    "Update %s.authenticate() to accept a positional "
-                    "`request` argument." % backend_path,
-                    RemovedInDjango21Warning
-                )
-        else:
-            credentials['request'] = request
-            warnings.warn(
-                "In %s.authenticate(), move the `request` keyword argument "
-                "to the first positional argument." % backend_path,
-                RemovedInDjango21Warning
-            )
-    return backend.authenticate(*args, **credentials)
-
-
 def login(request, user, backend=None):
     """
     Persist a user id and a backend in the request. This way a user doesn't
@@ -151,6 +118,9 @@ def login(request, user, backend=None):
                 'therefore must provide the `backend` argument or set the '
                 '`backend` attribute on the user.'
             )
+    else:
+        if not isinstance(backend, str):
+            raise TypeError('backend must be a dotted import path string (got %r).' % backend)
 
     request.session[SESSION_KEY] = user._meta.pk.value_to_string(user)
     request.session[BACKEND_SESSION_KEY] = backend
@@ -169,18 +139,10 @@ def logout(request):
     # Dispatch the signal before the user is logged out so the receivers have a
     # chance to find out *who* logged out.
     user = getattr(request, 'user', None)
-    if hasattr(user, 'is_authenticated') and not user.is_authenticated:
+    if not getattr(user, 'is_authenticated', True):
         user = None
     user_logged_out.send(sender=user.__class__, request=request, user=user)
-
-    # remember language choice saved to session
-    language = request.session.get(LANGUAGE_SESSION_KEY)
-
     request.session.flush()
-
-    if language is not None:
-        request.session[LANGUAGE_SESSION_KEY] = language
-
     if hasattr(request, 'user'):
         from django.contrib.auth.models import AnonymousUser
         request.user = AnonymousUser()
