@@ -24,22 +24,14 @@ class BaseDatabaseIntrospection:
         """
         return self.data_types_reverse[data_type]
 
-    def table_name_converter(self, name):
+    def identifier_converter(self, name):
         """
-        Apply a conversion to the name for the purposes of comparison.
+        Apply a conversion to the identifier for the purposes of comparison.
 
-        The default table name converter is for case sensitive comparison.
+        The default identifier converter is for case sensitive comparison.
         """
         return name
 
-    def column_name_converter(self, name):
-        """
-        Apply a conversion to the column name for the purposes of comparison.
-
-        Use table_name_converter() by default.
-        """
-        return self.table_name_converter(name)
-
     def table_names(self, cursor=None, include_views=False):
         """
         Return a list of names of all tables that exist in the database.
@@ -62,6 +54,16 @@ class BaseDatabaseIntrospection:
         """
         raise NotImplementedError('subclasses of BaseDatabaseIntrospection may require a get_table_list() method')
 
+    def get_migratable_models(self):
+        from django.apps import apps
+        from django.db import router
+        return (
+            model
+            for app_config in apps.get_app_configs()
+            for model in router.get_migratable_models(app_config, self.connection.alias)
+            if model._meta.can_migrate(self.connection)
+        )
+
     def django_table_names(self, only_existing=False, include_views=True):
         """
         Return a list of all table names that have associated Django models and
@@ -69,25 +71,22 @@ class BaseDatabaseIntrospection:
 
         If only_existing is True, include only the tables in the database.
         """
-        from django.apps import apps
-        from django.db import router
         tables = set()
-        for app_config in apps.get_app_configs():
-            for model in router.get_migratable_models(app_config, self.connection.alias):
-                if not model._meta.managed:
-                    continue
-                tables.add(model._meta.db_table)
-                tables.update(
-                    f.m2m_db_table() for f in model._meta.local_many_to_many
-                    if f.remote_field.through._meta.managed
-                )
+        for model in self.get_migratable_models():
+            if not model._meta.managed:
+                continue
+            tables.add(model._meta.db_table)
+            tables.update(
+                f.m2m_db_table() for f in model._meta.local_many_to_many
+                if f.remote_field.through._meta.managed
+            )
         tables = list(tables)
         if only_existing:
-            existing_tables = self.table_names(include_views=include_views)
+            existing_tables = set(self.table_names(include_views=include_views))
             tables = [
                 t
                 for t in tables
-                if self.table_name_converter(t) in existing_tables
+                if self.identifier_converter(t) in existing_tables
             ]
         return tables
 
@@ -96,15 +95,10 @@ class BaseDatabaseIntrospection:
         Return a set of all models represented by the provided list of table
         names.
         """
-        from django.apps import apps
-        from django.db import router
-        all_models = []
-        for app_config in apps.get_app_configs():
-            all_models.extend(router.get_migratable_models(app_config, self.connection.alias))
-        tables = list(map(self.table_name_converter, tables))
+        tables = set(map(self.identifier_converter, tables))
         return {
-            m for m in all_models
-            if self.table_name_converter(m._meta.db_table) in tables
+            m for m in self.get_migratable_models()
+            if self.identifier_converter(m._meta.db_table) in tables
         }
 
     def sequence_list(self):
@@ -112,24 +106,20 @@ class BaseDatabaseIntrospection:
         Return a list of information about all DB sequences for all models in
         all apps.
         """
-        from django.apps import apps
-        from django.db import router
-
         sequence_list = []
         with self.connection.cursor() as cursor:
-            for app_config in apps.get_app_configs():
-                for model in router.get_migratable_models(app_config, self.connection.alias):
-                    if not model._meta.managed:
-                        continue
-                    if model._meta.swapped:
-                        continue
-                    sequence_list.extend(self.get_sequences(cursor, model._meta.db_table, model._meta.local_fields))
-                    for f in model._meta.local_many_to_many:
-                        # If this is an m2m using an intermediate table,
-                        # we don't need to reset the sequence.
-                        if f.remote_field.through is None:
-                            sequence = self.get_sequences(cursor, f.m2m_db_table())
-                            sequence_list.extend(sequence or [{'table': f.m2m_db_table(), 'column': None}])
+            for model in self.get_migratable_models():
+                if not model._meta.managed:
+                    continue
+                if model._meta.swapped:
+                    continue
+                sequence_list.extend(self.get_sequences(cursor, model._meta.db_table, model._meta.local_fields))
+                for f in model._meta.local_many_to_many:
+                    # If this is an m2m using an intermediate table,
+                    # we don't need to reset the sequence.
+                    if f.remote_field.through._meta.auto_created:
+                        sequence = self.get_sequences(cursor, f.m2m_db_table())
+                        sequence_list.extend(sequence or [{'table': f.m2m_db_table(), 'column': None}])
         return sequence_list
 
     def get_sequences(self, cursor, table_name, table_fields=()):
