@@ -1,3 +1,5 @@
+import operator
+
 from django.db.backends.base.features import BaseDatabaseFeatures
 from django.utils.functional import cached_property
 
@@ -15,6 +17,7 @@ class DatabaseFeatures(BaseDatabaseFeatures):
     supports_date_lookup_using_string = False
     can_introspect_autofield = True
     can_introspect_binary_field = False
+    can_introspect_duration_field = False
     can_introspect_small_integer_field = True
     can_introspect_positive_integer_field = True
     introspected_boolean_field_type = 'IntegerField'
@@ -22,10 +25,8 @@ class DatabaseFeatures(BaseDatabaseFeatures):
     supports_timezones = False
     requires_explicit_null_ordering_when_grouping = True
     allows_auto_pk_0 = False
-    uses_savepoints = True
     can_release_savepoints = True
     atomic_transactions = False
-    supports_column_check_constraints = False
     can_clone_databases = True
     supports_temporal_subtraction = True
     supports_select_intersection = False
@@ -50,6 +51,8 @@ class DatabaseFeatures(BaseDatabaseFeatures):
     db_functions_convert_bytes_to_str = True
     # Alias MySQL's TRADITIONAL to TEXT for consistency with other backends.
     supported_explain_formats = {'JSON', 'TEXT', 'TRADITIONAL'}
+    # Neither MySQL nor MariaDB support partial indexes.
+    supports_partial_indexes = False
 
     @cached_property
     def _mysql_storage_engine(self):
@@ -66,10 +69,11 @@ class DatabaseFeatures(BaseDatabaseFeatures):
 
     @cached_property
     def has_zoneinfo_database(self):
-        # Test if the time zone definitions are installed.
+        # Test if the time zone definitions are installed. CONVERT_TZ returns
+        # NULL if 'UTC' timezone isn't loaded into the mysql.time_zone.
         with self.connection.cursor() as cursor:
-            cursor.execute("SELECT 1 FROM mysql.time_zone LIMIT 1")
-            return cursor.fetchone() is not None
+            cursor.execute("SELECT CONVERT_TZ('2001-01-01 01:00:00', 'UTC', 'UTC')")
+            return cursor.fetchone()[0] is not None
 
     @cached_property
     def is_sql_auto_is_null_enabled(self):
@@ -80,18 +84,39 @@ class DatabaseFeatures(BaseDatabaseFeatures):
 
     @cached_property
     def supports_over_clause(self):
+        if self.connection.mysql_is_mariadb:
+            return self.connection.mysql_version >= (10, 2)
         return self.connection.mysql_version >= (8, 0, 2)
 
     @cached_property
-    def has_select_for_update_skip_locked(self):
-        return self.connection.mysql_version >= (8, 0, 1)
+    def supports_column_check_constraints(self):
+        if self.connection.mysql_is_mariadb:
+            return self.connection.mysql_version >= (10, 2, 1)
+        return self.connection.mysql_version >= (8, 0, 16)
 
-    has_select_for_update_nowait = has_select_for_update_skip_locked
+    supports_table_check_constraints = property(operator.attrgetter('supports_column_check_constraints'))
+
+    @cached_property
+    def can_introspect_check_constraints(self):
+        if self.connection.mysql_is_mariadb:
+            version = self.connection.mysql_version
+            return (version >= (10, 2, 22) and version < (10, 3)) or version >= (10, 3, 10)
+        return self.connection.mysql_version >= (8, 0, 16)
+
+    @cached_property
+    def has_select_for_update_skip_locked(self):
+        return not self.connection.mysql_is_mariadb and self.connection.mysql_version >= (8, 0, 1)
+
+    @cached_property
+    def has_select_for_update_nowait(self):
+        if self.connection.mysql_is_mariadb:
+            return self.connection.mysql_version >= (10, 3, 0)
+        return self.connection.mysql_version >= (8, 0, 1)
 
     @cached_property
     def needs_explain_extended(self):
-        # EXTENDED is deprecated (and not required) in 5.7 and removed in 8.0.
-        return self.connection.mysql_version < (5, 7)
+        # EXTENDED is deprecated (and not required) in MySQL 5.7.
+        return not self.connection.mysql_is_mariadb and self.connection.mysql_version < (5, 7)
 
     @cached_property
     def supports_transactions(self):
@@ -106,3 +131,8 @@ class DatabaseFeatures(BaseDatabaseFeatures):
             cursor.execute('SELECT @@LOWER_CASE_TABLE_NAMES')
             result = cursor.fetchone()
             return result and result[0] != 0
+
+    @cached_property
+    def supports_default_in_lead_lag(self):
+        # To be added in https://jira.mariadb.org/browse/MDEV-12981.
+        return not self.connection.mysql_is_mariadb
