@@ -40,7 +40,7 @@ class HttpResponseBase:
         # the header (required for working with legacy systems) and the header
         # value. Both the name of the header and its value are ASCII strings.
         self._headers = {}
-        self._closable_objects = []
+        self._resource_closers = []
         # This parameter is set by the handler. It's necessary to preserve the
         # historical behavior of request_finished.
         self._handler_class = None
@@ -241,15 +241,14 @@ class HttpResponseBase:
 
     # The WSGI server must call this method upon completion of the request.
     # See http://blog.dscpl.com.au/2012/10/obligations-for-calling-close-on.html
-    # When wsgi.file_wrapper is used, the WSGI server instead calls close()
-    # on the file-like object. Django ensures this method is called in this
-    # case by replacing self.file_to_stream.close() with a wrapped version.
     def close(self):
-        for closable in self._closable_objects:
+        for closer in self._resource_closers:
             try:
-                closable.close()
+                closer()
             except Exception:
                 pass
+        # Free resources that were still referenced.
+        self._resource_closers.clear()
         self.closed = True
         signals.request_finished.send(sender=self._handler_class)
 
@@ -380,7 +379,7 @@ class StreamingHttpResponse(HttpResponseBase):
         # Ensure we can never iterate on "value" more than once.
         self._iterator = iter(value)
         if hasattr(value, 'close'):
-            self._closable_objects.append(value)
+            self._resource_closers.append(value.close)
 
     def __iter__(self):
         return self.streaming_content
@@ -400,39 +399,14 @@ class FileResponse(StreamingHttpResponse):
         self.filename = filename
         super().__init__(*args, **kwargs)
 
-    def _wrap_file_to_stream_close(self, filelike):
-        """
-        Wrap the file-like close() with a version that calls
-        FileResponse.close().
-        """
-        closing = False
-        filelike_close = getattr(filelike, 'close', lambda: None)
-
-        def file_wrapper_close():
-            nonlocal closing
-            # Prevent an infinite loop since FileResponse.close() tries to
-            # close the objects in self._closable_objects.
-            if closing:
-                return
-            closing = True
-            try:
-                filelike_close()
-            finally:
-                self.close()
-
-        filelike.close = file_wrapper_close
-
     def _set_streaming_content(self, value):
         if not hasattr(value, 'read'):
             self.file_to_stream = None
             return super()._set_streaming_content(value)
 
         self.file_to_stream = filelike = value
-        # Add to closable objects before wrapping close(), since the filelike
-        # might not have close().
         if hasattr(filelike, 'close'):
-            self._closable_objects.append(filelike)
-        self._wrap_file_to_stream_close(filelike)
+            self._resource_closers.append(filelike.close)
         value = iter(lambda: filelike.read(self.block_size), b'')
         self.set_headers(filelike)
         super()._set_streaming_content(value)
